@@ -1,7 +1,6 @@
-#copyright ReportLab Inc. 2000-2001
+#Copyright ReportLab Europe Ltd. 2000-2004
 #see license.txt for license details
-#history http://cvs.sourceforge.net/cgi-bin/cvsweb.cgi/docs/userguide/ch1_intro.py?cvsroot=reportlab
-#$Header: /cvsroot/reportlab/reportlab/docs/userguide/ch1_intro.py,v 1.14 2003/09/08 14:16:37 andy_robinson Exp $
+#history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/docs/userguide/ch1_intro.py
 from reportlab.tools.docco.rl_doc_utils import *
 import reportlab
 
@@ -187,7 +186,7 @@ latest stable version is also available as just $reportlab.zip$ (or
 $reportlab.tgz$), which is actually a symbolic link to the latest
 numbered version.""")
 
-disc("""We also make nightly snapshots of our CVS
+disc("""We also make nightly snapshots of our SVN
 (version control) tree available.  In
 general, these are very stable because we have a comprehensive test
 suite that all developers can run at any time.
@@ -567,4 +566,4 @@ bullet("""<b>Dive Into Python</b>.
 A free Python tutorial for experienced programmers.
 $http://diveintopython.org/$
 """)
-disc("")
\ No newline at end of file
+disc("")
