@@ -1,10 +1,10 @@
-#copyright ReportLab Inc. 2000
+#Copyright ReportLab Europe Ltd. 2000-2004
 #see license.txt for license details
-#history http://cvs.sourceforge.net/cgi-bin/cvsweb.cgi/docs/userguide/ch2_graphics.py?cvsroot=reportlab
-#$Header: /cvsroot/reportlab/reportlab/docs/userguide/ch2a_fonts.py,v 1.11 2004/01/20 22:50:31 andy_robinson Exp $
+#history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/docs/userguide/ch2a_fonts.py
 from reportlab.tools.docco.rl_doc_utils import *
 from reportlab.lib.codecharts import SingleByteEncodingChart
 from reportlab.platypus import Image
+import reportlab
 
 heading1("Fonts and encodings")
 
@@ -249,7 +249,7 @@ disc("""Since many users will not have the font packs installed, we have include
 a rather grainy ^bitmap^ of some Japanese characters.  We will discuss below what is needed to
 generate them.""")
 # include a bitmap of some Asian text
-I=os.path.join(os.path.dirname(__file__),'..','images','jpnchars.jpg')
+I=os.path.join(os.path.dirname(reportlab.__file__),'docs','images','jpnchars.jpg')
 try:
     getStory().append(Image(I))
 except:
@@ -653,4 +653,4 @@ and test #12 ('Test Various Fonts').""")
 
 
 
-##### FILL THEM IN
\ No newline at end of file
+##### FILL THEM IN
