@@ -1,8 +1,7 @@
-#copyright ReportLab Inc. 2000
+#Copyright ReportLab Europe Ltd. 2000-2004
 #see license.txt for license details
-#history http://cvs.sourceforge.net/cgi-bin/cvsweb.cgi/reportlab/platypus/test/testplatypus.py?cvsroot=reportlab
-#$Header: /cvsroot/reportlab/reportlab/test/test_platypus_general.py,v 1.13 2003/09/08 16:09:51 rgbecker Exp $
-__version__=''' $Id: test_platypus_general.py,v 1.13 2003/09/08 16:09:51 rgbecker Exp $ '''
+#history http://www.reportlab.co.uk/cgi-bin/viewcvs.cgi/public/reportlab/trunk/reportlab/test/test_platypus_general.py
+__version__=''' $Id: test_platypus_general.py 2438 2004-09-13 08:41:41Z rgbecker $ '''
 
 #tests and documents Page Layout API
 __doc__="""This is not obvious so here's a brief explanation.  This module is both
@@ -17,16 +16,30 @@ and drawn into.
 import string, copy, sys, os
 
 from reportlab.test import unittest
-from reportlab.test.utils import makeSuiteForClasses
+from reportlab.test.utils import makeSuiteForClasses, outputfile
 
 from reportlab.pdfgen import canvas
 from reportlab import platypus
 from reportlab.platypus import BaseDocTemplate, PageTemplate, Flowable, FrameBreak
-from reportlab.platypus import Paragraph
+from reportlab.platypus import Paragraph, Preformatted
 from reportlab.lib.units import inch, cm
 from reportlab.lib.styles import PropertySet, getSampleStyleSheet, ParagraphStyle
 from reportlab.lib import colors
 from reportlab.rl_config import defaultPageSize
+from reportlab.lib.utils import haveImages, _RL_DIR, rl_isfile, open_for_read
+if haveImages:
+    _GIF = os.path.join(_RL_DIR,'test','pythonpowered.gif')
+    if not rl_isfile(_GIF): _GIF = None
+else:
+    _GIF = None
+_JPG = os.path.join(_RL_DIR,'docs','images','lj8100.jpg')
+if not rl_isfile(_JPG): _JPG = None
+
+def getFurl(fn):
+    furl = fn.replace(os.sep,'/')
+    if sys.platform=='win32' and furl[1]==':': furl = furl[0]+'|'+furl[2:]
+    if furl[0]!='/': furl = '/'+furl
+    return 'file://'+furl
 
 PAGE_HEIGHT = defaultPageSize[1]
 
@@ -264,8 +277,55 @@ def getCommentary():
     story.append(Paragraph(
                 "The next example uses a custom font",
                 styleSheet['Italic']))
+    def code(txt,story=story,styleSheet=styleSheet):
+        story.append(Preformatted(txt,styleSheet['Code']))
+    code('''import reportlab.rl_config
+    reportlab.rl_config.warnOnMissingFontGlyphs = 0
+
+    from reportlab.pdfbase import pdfmetrics
+    fontDir = os.path.join(os.path.dirname(reportlab.__file__),'fonts')
+    face = pdfmetrics.EmbeddedType1Face(os.path.join(fontDir,'LeERC___.AFM'),
+            os.path.join(fontDir,'LeERC___.PFB'))
+    faceName = face.name  # should be 'LettErrorRobot-Chrome'
+    pdfmetrics.registerTypeFace(face)
+    font = pdfmetrics.Font(faceName, faceName, 'WinAnsiEncoding')
+    pdfmetrics.registerFont(font)
+
+
+    # put it inside a paragraph.
+    story.append(Paragraph(
+        """This is an ordinary paragraph, which happens to contain
+        text in an embedded font:
+        <font name="LettErrorRobot-Chrome">LettErrorRobot-Chrome</font>.
+        Now for the real challenge...""", styleSheet['Normal']))
+
+
+    styRobot = ParagraphStyle('Robot', styleSheet['Normal'])
+    styRobot.fontSize = 16
+    styRobot.leading = 20
+    styRobot.fontName = 'LettErrorRobot-Chrome'
+
+    story.append(Paragraph(
+                "This whole paragraph is 16-point Letterror-Robot-Chrome.",
+                styRobot))''')
 
     story.append(FrameBreak())
+    if _GIF:
+        story.append(Paragraph("""We can use images via the file name""", styleSheet['BodyText']))
+        code('''    story.append(platypus.Image('%s'))'''%_GIF)
+        code('''    story.append(platypus.Image('%s'.encode('utf8')))''' % _GIF)
+        story.append(Paragraph("""They can also be used with a file URI or from an open python file!""", styleSheet['BodyText']))
+        code('''    story.append(platypus.Image('%s'))'''% getFurl(_GIF))
+        code('''    story.append(platypus.Image(open_for_read('%s','b')))''' % _GIF)
+        story.append(FrameBreak())
+        story.append(Paragraph("""Images can even be obtained from the internet.""", styleSheet['BodyText']))
+        code('''    img = platypus.Image('http://www.reportlab.com/rsrc/encryption.gif')
+    story.append(img)''')
+        story.append(FrameBreak())
+
+    if _JPG:
+        story.append(Paragraph("""JPEGs are a native PDF image format. They should be available even if PIL cannot be used.""", styleSheet['BodyText']))
+        story.append(FrameBreak())
     return story
 
 def getExamples():
@@ -360,7 +420,7 @@ def getExamples():
         return (self.width, self.height)
     '''
 
-    story.append(platypus.Preformatted(code, styleSheet['Code'], dedent=4))
+    story.append(Preformatted(code, styleSheet['Code'], dedent=4))
     story.append(FrameBreak())
     #######################################################################
     #     Examples Page 3
@@ -373,18 +433,6 @@ def getExamples():
     story.append(Paragraph("This is a bullet point", styleSheet['Bullet'], bulletText='O'))
     story.append(Paragraph("Another bullet point", styleSheet['Bullet'], bulletText='O'))
 
-    story.append(Paragraph(
-                "Here is an Image.  For now, these are always centred in the frame.",
-                styleSheet['Italic']))
-
-    from reportlab.lib.utils import haveImages
-    if haveImages:
-        story.append(Paragraph(
-                "Here is an Image.  For now, these are always centred in the frame.",
-                styleSheet['Italic']))
-
-        img = platypus.Image('pythonpowered.gif')
-        story.append(img)
 
     story.append(Paragraph("""Here is a Table, which takes all kinds of formatting options...""",
                 styleSheet['Italic']))
@@ -413,8 +461,6 @@ def getExamples():
     #######################################################################
     #     Examples Page 4 - custom fonts
     #######################################################################
-
-
     # custom font with Wargames font
     import reportlab.rl_config
     reportlab.rl_config.warnOnMissingFontGlyphs = 0
@@ -446,6 +492,33 @@ def getExamples():
                 styWargames))
     story.append(FrameBreak())
 
+    if _GIF:
+        story.append(Paragraph("Here is an Image flowable obtained from a string filename.",styleSheet['Italic']))
+        story.append(platypus.Image(_GIF))
+        story.append(Paragraph( "Here is an Image flowable obtained from a utf8 filename.", styleSheet['Italic']))
+        story.append(platypus.Image(_GIF.encode('utf8')))
+        story.append(Paragraph("Here is an Image flowable obtained from a string file url.",styleSheet['Italic']))
+        story.append(platypus.Image(getFurl(_GIF)))
+        story.append(Paragraph("Here is an Image flowable obtained from an open file.",styleSheet['Italic']))
+        story.append(platypus.Image(open_for_read(_GIF,'b')))
+        story.append(FrameBreak())
+        try:
+            img = platypus.Image('http://www.reportlab.com/rsrc/encryption.gif')
+            story.append(Paragraph("Here is an Image flowable obtained from a string http url.",styleSheet['Italic']))
+            story.append(img)
+        except:
+            story.append(Paragraph("The image could not be obtained from a string http url.",styleSheet['Italic']))
+        story.append(FrameBreak())
+
+    if _JPG:
+        img = platypus.Image(_JPG)
+        story.append(Paragraph("Here is an JPEG Image flowable obtained from a filename.",styleSheet['Italic']))
+        story.append(img)
+        story.append(Paragraph("Here is an JPEG Image flowable obtained from an open file.",styleSheet['Italic']))
+        img = platypus.Image(open_for_read(_JPG,'b'))
+        story.append(img)
+        story.append(FrameBreak())
+
 
     return story
 
@@ -480,7 +553,7 @@ def showProgress(pageNo):
 
 
 def run():
-    doc = AndyTemplate('test_platypus_general.pdf')
+    doc = AndyTemplate(outputfile('test_platypus_general.pdf'))
     #doc.setPageCallBack(showProgress)
     commentary = getCommentary()
     examples = getExamples()
